@@ -588,6 +588,8 @@ namespace xcas {
       //int ck=browser->value();
       browser->value(i);
       for (;;) {
+	if (!handle_tab_w->visible())
+          handle_tab_w->show();
 #if 0 // ndef EMCC2
 	if (!handle_tab_w->shown()){
 	  r=0; break;
