@@ -1443,7 +1443,7 @@ std::string get_string(const std::string & in){
 #endif
 
 void end_icas(){
-#ifdef HAVE_SIGNAL_H
+#if defined HAVE_SIGNAL_H && !defined __MINGW_H
   if (giac::child_id>1){
     cerr << "Killing child process " << giac::child_id << "\n";
     kill(giac::child_id,SIGKILL);
@@ -1467,6 +1467,7 @@ int main(int ARGC, char *ARGV[]){
   bool insage=((ARGC>=2) && std::string(ARGV[1])=="--sage");
   bool intexmacs=((ARGC>=2) && std::string(ARGV[1])=="--texmacs");
   if (intexmacs) suspend_stderr(); // suppress stderr output when in texmacs (L. Marohnić)
+  if (getenv("GIAC_WARN")) giac::warn_symb_program_sto=atoi(getenv("GIAC_WARN"));
 #ifdef HAVE_LIBFLTK
 #if !defined(__APPLE__) && !defined(WIN32)
   if (getenv("DISPLAY"))
